@@ -7,7 +7,7 @@ from EPCPyYes.core.v1_2.CBV.dispositions import Disposition
 from EPCPyYes.core.v1_2.events import EventType
 from quartet_capture.models import Rule, Step, StepParameter, Task
 from quartet_capture.tasks import execute_rule
-from quartet_epcis.parsing.business_parser import BusinessEPCISParser
+from quartet_epcis.parsing.context_parser import BusinessEPCISParser
 from quartet_output import models
 from quartet_output.models import EPCISOutputCriteria
 from quartet_output.steps import ContextKeys
@@ -179,7 +179,7 @@ class TestOutputParsing(TestCase):
                 12,
                 "There should be twelve filtered events."
             )
-            task_name = context.context[ContextKeys.CREATED_TASK_NAME_KEY]
+            task_name = context.context[ContextKeys.CREATED_TASK_NAME_KEY.value]
             task = Task.objects.get(name=task_name)
             self.assertEqual(task.status, 'FINISHED')
             print(context.context[ContextKeys.OUTBOUND_EPCIS_MESSAGE_KEY.value])
