@@ -22,7 +22,7 @@ from EPCPyYes.core.v1_2.CBV.dispositions import Disposition
 from EPCPyYes.core.v1_2.events import EventType
 from quartet_capture.models import Rule, Step, StepParameter, Task
 from quartet_capture.tasks import execute_rule, execute_queued_task
-from quartet_epcis.parsing.business_parser import BusinessEPCISParser
+from quartet_epcis.parsing.context_parser import BusinessEPCISParser
 from quartet_output import models
 from quartet_output.models import EPCISOutputCriteria
 from quartet_output.steps import SimpleOutputParser, ContextKeys
@@ -179,7 +179,7 @@ class TestQuartetOutput(TestCase):
                     self.assertEqual(len(event.child_epcs), 5)
                 else:
                     self.assertEqual(len(event.child_epcs), 2)
-            task_name = context.context[ContextKeys.CREATED_TASK_NAME_KEY]
+            task_name = context.context[ContextKeys.CREATED_TASK_NAME_KEY.value]
             execute_queued_task(task_name=task_name)
             task = Task.objects.get(name=task_name)
             self.assertEqual(task.status, 'FINISHED')
@@ -214,7 +214,7 @@ class TestQuartetOutput(TestCase):
                     self.assertEqual(len(event.child_epcs), 5)
                 else:
                     self.assertEqual(len(event.child_epcs), 2)
-            task_name = context.context[ContextKeys.CREATED_TASK_NAME_KEY]
+            task_name = context.context[ContextKeys.CREATED_TASK_NAME_KEY.value]
             execute_queued_task(task_name=task_name)
             task = Task.objects.get(name=task_name)
             self.assertEqual(task.status, 'FINISHED')
@@ -251,7 +251,7 @@ class TestQuartetOutput(TestCase):
                     self.assertEqual(len(event.child_epcs), 5)
                 else:
                     self.assertEqual(len(event.child_epcs), 2)
-            task_name = context.context[ContextKeys.CREATED_TASK_NAME_KEY]
+            task_name = context.context[ContextKeys.CREATED_TASK_NAME_KEY.value]
             execute_queued_task(task_name=task_name)
             task = Task.objects.get(name=task_name)
             self.assertEqual(task.status, 'FINISHED')
@@ -277,7 +277,7 @@ class TestQuartetOutput(TestCase):
                 ContextKeys.FILTERED_EVENTS_KEY.value
             ]:
                 self.assertIsInstance(event, sbdheader)
-            task_name = context.context[ContextKeys.CREATED_TASK_NAME_KEY]
+            task_name = context.context[ContextKeys.CREATED_TASK_NAME_KEY.value]
             execute_queued_task(task_name=task_name)
             task = Task.objects.get(name=task_name)
             self.assertEqual(task.status, 'FINISHED')
@@ -312,7 +312,7 @@ class TestQuartetOutput(TestCase):
                     self.assertEqual(len(event.child_epcs), 5)
                 else:
                     self.assertEqual(len(event.child_epcs), 2)
-            task_name = context.context[ContextKeys.CREATED_TASK_NAME_KEY]
+            task_name = context.context[ContextKeys.CREATED_TASK_NAME_KEY.value]
             execute_queued_task(task_name=task_name)
             task = Task.objects.get(name=task_name)
             self.assertEqual(task.status, 'FINISHED')
@@ -408,7 +408,8 @@ class TestQuartetOutput(TestCase):
             except EPCISOutputCriteria.DoesNotExist:
                 pass
         stop = time.time()
-        self.assertGreaterEqual((stop - start), 3, 'The rule did not pause '
+        execution_time = round((stop - start))
+        self.assertGreaterEqual(execution_time, 3, 'The rule did not pause '
                                                    'long enough.')
 
     def _create_good_ouput_criterion(self):
@@ -466,7 +467,7 @@ class TestQuartetOutput(TestCase):
 
     def _create_endpoint(self):
         ep = models.EndPoint()
-        ep.urn = getattr(settings, 'TEST_SERVER', 'http://testhost')
+        ep.urn = getattr(settings, 'TEST_SERVER', 'http://testhost:8080')
         ep.name = 'Test EndPoint'
         ep.save()
         return ep
@@ -724,7 +725,7 @@ class TestSFTPTransport(TestQuartetOutput):
                 ContextKeys.FILTERED_EVENTS_KEY.value
             ]:
                 self.assertIsInstance(event, sbdheader)
-            task_name = context.context[ContextKeys.CREATED_TASK_NAME_KEY]
+            task_name = context.context[ContextKeys.CREATED_TASK_NAME_KEY.value]
             execute_queued_task(task_name=task_name)
             task = Task.objects.get(name=task_name)
             self.assertEqual(task.status, 'FINISHED')
